#!/usr/bin/perl
# nagios: -epn
## $Id: check_file_exist (shell script) by Diego Martin Gardella [dgardella@gmail.com] / perl by J.Ph. LEMOINE$

# Desc : Plugin to verify if a file exists
# Modify : Jean-Philippe LEMOINE : translate mecanism
#

## Nagios Plugin to verify if a file exists
## Diego Martin Gardella [dgardella@gmail.com]

## modified by Jean-Philippe LEMOINE (Add status parameter)
## modified for being in perl for purpose of being 
## easily translate.

##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

use strict;
use warnings;
use Switch;
use Config::INI::Reader;
use Nagios::Plugin;
use vars qw/ $VERSION /;
use lib "/usr/lib/perl5/B";

$VERSION = '1.0';
my $LICENCE = "Ce plugin Nagios est gratuit et libre de droits, et vous pouvez l'utiliser à votre convenance."
  . ' Il est livré avec ABSOLUMENT AUCUNE GARANTIE.';

my $plugin_nagios = Nagios::Plugin->new(
  shortname => 'check_file_exist',
  usage     => 'Usage : %s ',
  version   => $VERSION,
  license   => $LICENCE,
);

my $PROGNAME=`basename $0`;
chomp($PROGNAME);
my $NAME_INI=substr $PROGNAME, 0, -3;

# put the 2 letters of the country code
# in 10/28/2012, there is 2 possibilies :
# fr for french
# en for english
my $country_code_def="fr";

$plugin_nagios->add_arg(
  spec     => 'file|f=s',
  help     => '<file to check>',    # Aide au sujet de cette option
  required => 1,                  # Argument obligatoire
);


$plugin_nagios->add_arg(
spec     => 'exist|e=s',
help     => 'exist ("O")ou not exist ("N")',    # Aide au sujet de cette option
required => 1,                  # Argument obligatoire
);


$plugin_nagios->add_arg(
spec     => 'lang|l=s',
help     => 'fr ou en',    # Aide au sujet de cette option
required => 0,                  # Argument facultatif
);

$plugin_nagios->add_arg(
spec     => 'ini_file|i=s',
help     => 'ini file name',    # Aide au sujet de cette option
required => 0,                  # Argument facultatif
);

$plugin_nagios->getopts();


my $FILE       = $plugin_nagios->opts->get('file');
my $FLAG_EXIST = $plugin_nagios->opts->get('exist');
my $COUNTRY_CODE = $plugin_nagios->opts->get('lang');
my $INI_FILE = $plugin_nagios->opts->get('ini_file');

# check parameter : if diffrent of status, warn & crit is mandatory

sub display_usage()
    {
    print "Usage : ${PROGNAME}\n";
    print "\n";
    print "Missing argument: $_[0]\n";
    }

# check parameter

if (($FILE eq ''))
    {
    print "1st parameter : need a file name";
    exit 3;
    }

if (($FLAG_EXIST ne 'O') && ($FLAG_EXIST ne 'N'))
    {
        # flag exist must be 'O' ou 'N'
        &display_usage("2nd parameter must be 'O' ou 'N'");
        exit 3;
    }

# ---- fin recup parametre

# check if translation file exists
# if not, try to use default one

if (!(defined($COUNTRY_CODE)))
    {
    $COUNTRY_CODE = $country_code_def;
    }

if (defined($INI_FILE))
{
    #print "\nini_file='${INI_FILE}'\n";
    $NAME_INI = $INI_FILE;
}
#else {print "\nini_file indefini.\n";}

my $ini_file = "${NAME_INI}_${COUNTRY_CODE}.ini";
if (!(-e $ini_file))
{
  # fichier traduc inexistant, lecture defaut
  $ini_file = "${NAME_INI}.ini";
  if (!(-e $ini_file))
    {
    print "fatal error : conf file (${ini_file}) not found";
    exit 3;
    } 
}


#put translations in memory
my $hash_ref = Config::INI::Reader->read_file($ini_file);
# display help notice
sub dishelp() {
                 my $help01a=$hash_ref->{help}->{help01a};                
                 my $help01b=$hash_ref->{help}->{help01b};                
                 print "$help01a \n$0 $help01b\n";
		 exit 3;
}

# function trim for suppress leadind spaces
sub trim {
    (my $s = $_[0]) =~ s/^\s+|\s+$//g;
    return $s;        
}

# test the (in)existence of the file in parameter
my $RETOUR='';
my $DISP='';

if (-e $FILE) {
    $DISP='O';
    if ($FLAG_EXIST eq 'O')
        {$RETOUR= 'OK';}
    else
        {$RETOUR= 'KO';}
} 
else { 
    $DISP='N';
    if ($FLAG_EXIST eq 'O')
        {$RETOUR= 'KO';}
    else
        {$RETOUR= 'OK';}
}

my $LIGNE='';

my $STATE_CRIT=$hash_ref->{STATE}->{CRIT};
my $STATE_OK  =$hash_ref->{STATE}->{OK};
my $NB_LIG=$hash_ref->{AFFICHE}->{NB_LIG};
my $AFFICHE_CRIT_E=$hash_ref->{AFFICHE}->{CRIT_E};
my $AFFICHE_CRIT_N=$hash_ref->{AFFICHE}->{CRIT_N};
my $AFFICHE_OK_E=$hash_ref->{AFFICHE}->{OK_E};
my $AFFICHE_OK_N=$hash_ref->{AFFICHE}->{OK_N};

if ($RETOUR eq 'KO')
{
    if ($DISP eq 'O')
    {
        $LIGNE=`head -${NB_LIG} ${FILE} | awk 'BEGIN {ORS=" "} {print} END {print "\\n"}'`;
        my $LCRIT= eval "print \"${AFFICHE_CRIT_E}\"";
        print $LCRIT;
    }
    else
    {
        my $LCRIT= eval "print \"${AFFICHE_CRIT_N}\"";
        print $LCRIT;
    }
    exit 2;
}
else
{
    # retour ok
    if ($DISP eq 'O')
    {
        $LIGNE=`head -${NB_LIG} ${FILE} | awk 'BEGIN {ORS=" "} {print} END {print "\\n"}'`;        
        my $LCRIT= eval "print \"${AFFICHE_OK_E}\"";
        print $LCRIT;

    }
    else
    {
        #print "\n\"${AFFICHE_OK_N}\"\n";
        my $LCRIT= eval "print \"${AFFICHE_OK_N}\"";
        print $LCRIT;
    }
    exit 0;
}

&dishelp("--");
exit 3;


